{% load humanize %}

<div
    class="progress-bar progress-bar-{{ level }} task-status-progress-bar"
    role="progressbar"
    aria-valuenow="{% widthratio tasks_count tasks_total 100 %}"
    aria-valuemin="0"
    aria-valuemax="100"
    style="width: {% widthratio tasks_count tasks_total 100 %}%;"
    title="{{ tasks_count|intcomma }} {{ label }}">
    {% widthratio tasks_count tasks_total 100 %}%
</div>
